@@ -13,6 +13,7 @@ if __name__ == '__main__':
         sys.path = python_path
         
         from nesoni import legion
+            
         legion.manager(address, authkey, connect=True)
         
         if main_file is not None: # so unpickling functions in __main__ works
@@ -331,8 +332,10 @@ class My_manager(managers.SyncManager):
             signal.signal(signal.SIGINT, signal.SIG_IGN)
             managers.SyncManager._Server.serve_forever(self)
     
+def _get_coordinator():
+    return _COORDINATOR
+My_manager.register('get_coordinator', callable=_get_coordinator)
 
-My_manager.register('get_coordinator', callable=lambda: _COORDINATOR)
 
 _MANAGER = None
 _AUTHKEY = None
@@ -349,8 +352,7 @@ def manager(address=('127.0.0.1',0),authkey=None,connect=False):
     global _MANAGER, _AUTHKEY
     if _MANAGER is None:
         if authkey is None:
-            with open('/dev/urandom','rb') as f:
-                authkey = base64.b16encode(f.read(256))
+            authkey = base64.b16encode(os.urandom(256))
         _MANAGER = My_manager(address=address, authkey=authkey)
         _AUTHKEY = authkey
         if connect:
